==> libreoffice-fresh-sdk-25.8.4-1-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.js <==
var servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties =
[
    [ "ParaInteropGrabBag", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a3e9b181bcbfaef89beabe673da9efe4e", null ],
    [ "ParaTabStops", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a13c2609eb1f2f8e9e8402d97f8954e60", null ],
    [ "BorderDistance", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a98a0c98b6dc7134e33d5c683e277229c", null ],
    [ "BottomBorder", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a76ed69ba5cbc1b15fa0d64aca4850106", null ],
    [ "BottomBorderDistance", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#afd16edc08d37e72058487182531f8c61", null ],
    [ "BreakType", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a811faa172ad4ec80c90180f8628686d0", null ],
    [ "ContinueingPreviousSubTree", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a000a5b9db93d58041f54d6f08d027717", null ],
    [ "DropCapCharStyleName", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a9cc10849cbb423d1fc07a5b46edf1d0c", null ],
    [ "DropCapFormat", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a809dee8b5bd773284ae4cc33f5230e98", null ],
    [ "DropCapWholeWord", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#aa783b74be22ae0f38ffc445c7667207d", null ],
    [ "LeftBorder", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#afc5673d7ea472362ba3dfd1f1b891f3c", null ],
    [ "LeftBorderDistance", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#aa525416639863f2dbee49aff512d0edc", null ],
    [ "ListId", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a459e269cd6c19cd01214239ec972bdf5", null ],
    [ "ListLabelString", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#af58f5a5ac65f3aaf4b11c9faf2ea4a1c", null ],
    [ "NumberingIsNumber", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a66fd8645701ca3c5ae6b574f0fad6a7c", null ],
    [ "NumberingLevel", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a9a3a02cc97d4f72f4c66d91390ac3787", null ],
    [ "NumberingRules", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#aed1885e6b2631c15f6ac8c832473c1e2", null ],
    [ "NumberingStartValue", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a78bad51c5a40eef7a8d372b3ff62b9b9", null ],
    [ "NumberingStyleName", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#aeade2dbdd2b5a679a2d360e2eb4eea28", null ],
    [ "OutlineLevel", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a99be1f0af0b200d63f62712721bd26c1", null ],
    [ "PageDescName", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#adebb01c5a68776d99c4598b5ecb2fca4", null ],
    [ "PageNumberOffset", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a90cbc0a25c6bbf1b98cfdeee2777557e", null ],
    [ "PageStyleName", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a37ddb97ccd5a589ce2cae9e3d60ec037", null ],
    [ "ParaAdjust", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#afd3fb862a8fc11961f5d32521dc3cbc6", null ],
    [ "ParaBackColor", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#ad0a118d32f5e7345c01323d4398eff1d", null ],
    [ "ParaBackGraphic", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#ad65e41920f1da00b6474d44fd464d05a", null ],
    [ "ParaBackGraphicFilter", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a2148d5654abbce290582f9da6ba6568a", null ],
    [ "ParaBackGraphicLocation", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#aabd1a6e9a4d31dd8b884b4b827cea676", null ],
    [ "ParaBackGraphicURL", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#ad5c02610a7cbab4359e964494626dffd", null ],
    [ "ParaBackTransparent", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#aeb22ef33fbdfd8817ce3b468c15c0adb", null ],
    [ "ParaBottomMargin", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a468a4fc42d26192c0eab945c470b27ad", null ],
    [ "ParaContextMargin", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a54eca40da6688e54c93897b493143054", null ],
    [ "ParaExpandSingleWord", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a2ad1811fee62d1c78076f08c13c3c842", null ],
    [ "ParaFirstLineIndent", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a99765584e7bb2f15eaa8d80d67259be9", null ],
    [ "ParaHyphenationCompoundMinLeadingChars", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a846a369dbdd45d1e5740b67639b6871e", null ],
    [ "ParaHyphenationKeep", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a60376e41340cda4717931445580529d0", null ],
    [ "ParaHyphenationKeepLine", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a8f2ce48cdc6d0371861916b03129ccaf", null ],
    [ "ParaHyphenationKeepType", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a6af1b97429625476b08e6089a5976c37", null ],
    [ "ParaHyphenationMaxHyphens", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#af4945f0404d7658566def5e73ccead27", null ],
    [ "ParaHyphenationMaxLeadingChars", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#af271ae61d3186fefc0005f6a6cccdcdb", null ],
    [ "ParaHyphenationMaxTrailingChars", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a99beb3bc9035dae1bda1a4255de91938", null ],
    [ "ParaHyphenationMinWordLength", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#af9214d5455d2b7244a50090cbe8ef836", null ],
    [ "ParaHyphenationNoCaps", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a6b6fdac420ab18161bbcdfca3c07715e", null ],
    [ "ParaHyphenationNoLastWord", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#acebc56962e87475c1f05f8e3d544852a", null ],
    [ "ParaHyphenationZone", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a2ec6d489b912c38eab02f915db09add9", null ],
    [ "ParaHyphenationZoneAlways", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a32e54dab1c5ad55c0fabd7fc0934a6b3", null ],
    [ "ParaHyphenationZoneColumn", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a184bece457b41dca4c2e8d16383e74d5", null ],
    [ "ParaHyphenationZonePage", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#ad6cedff99ecb5bc869546ffa052e98c2", null ],
    [ "ParaHyphenationZoneSpread", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a5e58be35c30ac8fedd19279646925d95", null ],
    [ "ParaIsAutoFirstLineIndent", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a8d3e9263642b9befce070e4642c65e1a", null ],
    [ "ParaIsConnectBorder", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#ab98cbc2fbeafdf5dee60263f1bbe8704", null ],
    [ "ParaIsHyphenation", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a4738959eed70e9b0ac839fced5f63df9", null ],
    [ "ParaIsNumberingRestart", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a74afce590710b8b795289adfdb8381c8", null ],
    [ "ParaKeepTogether", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a8e775668a7c04e29e91f43b75a0d5acd", null ],
    [ "ParaLastLineAdjust", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a6265c9853bda78e2f2a344e52814c7b0", null ],
    [ "ParaLeftMargin", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a9640f9110480558dcc66d794f67f57b8", null ],
    [ "ParaLineNumberCount", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a3b6a4c7047c80633bb1276f8f84fa51c", null ],
    [ "ParaLineNumberStartValue", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#ae894862331f3b1ca98b92265a4adae6a", null ],
    [ "ParaLineSpacing", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a119d0f6e1f7d2b8696a8a4331c4e1bcd", null ],
    [ "ParaOrphans", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a72ee90130da054ca09b368a696627c83", null ],
    [ "ParaRegisterModeActive", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a81fad24b2a038b3cb1bc5157ac6339e4", null ],
    [ "ParaRightMargin", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a3ea3a3aad18ac347858caafeeb726977", null ],
    [ "ParaShadowFormat", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#ab06662e42c2a36f97ce4e18bbd0487aa", null ],
    [ "ParaSplit", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#afacdd63738ba4e3a08040e39289b0ecc", null ],
    [ "ParaStyleName", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#aeac9fbec555fddbf8219c8ea94ae7bd2", null ],
    [ "ParaTopMargin", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#ac6ca70814d30943ebe921504dd41ea8f", null ],
    [ "ParaUserDefinedAttributes", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a0b0bde2406663d5f6460ba94b23ae66a", null ],
    [ "ParaVertAlignment", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a067215b0b4788aba57fc66dcf94026db", null ],
    [ "ParaWidows", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a3072d8ed7bf43be2ae34409abaeb9a50", null ],
    [ "ParaWordSpacing", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#aa73036ac6184c50be858e0961a045dad", null ],
    [ "ParaWordSpacingMaximum", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a7a7a6085a7e251d3b9665e5dce9c16fe", null ],
    [ "ParaWordSpacingMinimum", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a950c52f87cfa65cf332cd3693d429a07", null ],
    [ "RightBorder", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a5a63000f5a2a2472e3e4ff55b3acea68", null ],
    [ "RightBorderDistance", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#aef3133d206f65e7c63e6f4e0b7e81a9b", null ],
    [ "SortedTextId", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a895e2661a30250caf988246e0078f203", null ],
    [ "TopBorder", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a17ab3611edf21b072bf9963d28fbba0d", null ],
    [ "TopBorderDistance", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a244f38805668926e16165aab20b80f01", null ]
];

==> libreoffice-fresh-sdk-26.2.0-4-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.js <==
var servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties =
[
    [ "ParaInteropGrabBag", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a3e9b181bcbfaef89beabe673da9efe4e", null ],
    [ "ParaTabStops", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a13c2609eb1f2f8e9e8402d97f8954e60", null ],
    [ "BorderDistance", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a98a0c98b6dc7134e33d5c683e277229c", null ],
    [ "BottomBorder", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a76ed69ba5cbc1b15fa0d64aca4850106", null ],
    [ "BottomBorderDistance", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#afd16edc08d37e72058487182531f8c61", null ],
    [ "BreakType", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a811faa172ad4ec80c90180f8628686d0", null ],
    [ "ContinueingPreviousSubTree", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a000a5b9db93d58041f54d6f08d027717", null ],
    [ "DropCapCharStyleName", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a9cc10849cbb423d1fc07a5b46edf1d0c", null ],
    [ "DropCapFormat", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a809dee8b5bd773284ae4cc33f5230e98", null ],
    [ "DropCapWholeWord", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#aa783b74be22ae0f38ffc445c7667207d", null ],
    [ "LeftBorder", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#afc5673d7ea472362ba3dfd1f1b891f3c", null ],
    [ "LeftBorderDistance", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#aa525416639863f2dbee49aff512d0edc", null ],
    [ "ListId", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a459e269cd6c19cd01214239ec972bdf5", null ],
    [ "ListLabelString", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#af58f5a5ac65f3aaf4b11c9faf2ea4a1c", null ],
    [ "NumberingIsNumber", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a66fd8645701ca3c5ae6b574f0fad6a7c", null ],
    [ "NumberingLevel", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a9a3a02cc97d4f72f4c66d91390ac3787", null ],
    [ "NumberingRules", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#aed1885e6b2631c15f6ac8c832473c1e2", null ],
    [ "NumberingStartValue", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a78bad51c5a40eef7a8d372b3ff62b9b9", null ],
    [ "NumberingStyleName", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#aeade2dbdd2b5a679a2d360e2eb4eea28", null ],
    [ "OutlineLevel", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a99be1f0af0b200d63f62712721bd26c1", null ],
    [ "PageDescName", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#adebb01c5a68776d99c4598b5ecb2fca4", null ],
    [ "PageNumberOffset", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a90cbc0a25c6bbf1b98cfdeee2777557e", null ],
    [ "PageStyleName", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a37ddb97ccd5a589ce2cae9e3d60ec037", null ],
    [ "ParaAdjust", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#afd3fb862a8fc11961f5d32521dc3cbc6", null ],
    [ "ParaBackColor", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#ad0a118d32f5e7345c01323d4398eff1d", null ],
    [ "ParaBackGraphic", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#ad65e41920f1da00b6474d44fd464d05a", null ],
    [ "ParaBackGraphicFilter", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a2148d5654abbce290582f9da6ba6568a", null ],
    [ "ParaBackGraphicLocation", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#aabd1a6e9a4d31dd8b884b4b827cea676", null ],
    [ "ParaBackGraphicURL", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#ad5c02610a7cbab4359e964494626dffd", null ],
    [ "ParaBackTransparent", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#aeb22ef33fbdfd8817ce3b468c15c0adb", null ],
    [ "ParaBottomMargin", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a468a4fc42d26192c0eab945c470b27ad", null ],
    [ "ParaContextMargin", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a54eca40da6688e54c93897b493143054", null ],
    [ "ParaExpandSingleWord", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a2ad1811fee62d1c78076f08c13c3c842", null ],
    [ "ParaFirstLineIndent", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a99765584e7bb2f15eaa8d80d67259be9", null ],
    [ "ParaHyphenationCompoundMinLeadingChars", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a846a369dbdd45d1e5740b67639b6871e", null ],
    [ "ParaHyphenationKeep", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a60376e41340cda4717931445580529d0", null ],
    [ "ParaHyphenationKeepLine", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a8f2ce48cdc6d0371861916b03129ccaf", null ],
    [ "ParaHyphenationKeepType", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a6af1b97429625476b08e6089a5976c37", null ],
    [ "ParaHyphenationMaxHyphens", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#af4945f0404d7658566def5e73ccead27", null ],
    [ "ParaHyphenationMaxLeadingChars", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#af271ae61d3186fefc0005f6a6cccdcdb", null ],
    [ "ParaHyphenationMaxTrailingChars", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a99beb3bc9035dae1bda1a4255de91938", null ],
    [ "ParaHyphenationMinWordLength", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#af9214d5455d2b7244a50090cbe8ef836", null ],
    [ "ParaHyphenationNoCaps", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a6b6fdac420ab18161bbcdfca3c07715e", null ],
    [ "ParaHyphenationNoLastWord", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#acebc56962e87475c1f05f8e3d544852a", null ],
    [ "ParaHyphenationZone", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a2ec6d489b912c38eab02f915db09add9", null ],
    [ "ParaHyphenationZoneAlways", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a32e54dab1c5ad55c0fabd7fc0934a6b3", null ],
    [ "ParaHyphenationZoneColumn", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a184bece457b41dca4c2e8d16383e74d5", null ],
    [ "ParaHyphenationZonePage", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#ad6cedff99ecb5bc869546ffa052e98c2", null ],
    [ "ParaHyphenationZoneSpread", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a5e58be35c30ac8fedd19279646925d95", null ],
    [ "ParaIsAutoFirstLineIndent", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a8d3e9263642b9befce070e4642c65e1a", null ],
    [ "ParaIsConnectBorder", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#ab98cbc2fbeafdf5dee60263f1bbe8704", null ],
    [ "ParaIsHyphenation", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a4738959eed70e9b0ac839fced5f63df9", null ],
    [ "ParaIsNumberingRestart", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a74afce590710b8b795289adfdb8381c8", null ],
    [ "ParaKeepTogether", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a8e775668a7c04e29e91f43b75a0d5acd", null ],
    [ "ParaLastLineAdjust", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a6265c9853bda78e2f2a344e52814c7b0", null ],
    [ "ParaLeftMargin", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a9640f9110480558dcc66d794f67f57b8", null ],
    [ "ParaLetterSpacingMaximum", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a2f6ffc70a3cdcdeea13e595a5e270b41", null ],
    [ "ParaLetterSpacingMinimum", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a04978110c51124753f8140ca0e41f3dc", null ],
    [ "ParaLineNumberCount", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a3b6a4c7047c80633bb1276f8f84fa51c", null ],
    [ "ParaLineNumberStartValue", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#ae894862331f3b1ca98b92265a4adae6a", null ],
    [ "ParaLineSpacing", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a119d0f6e1f7d2b8696a8a4331c4e1bcd", null ],
    [ "ParaOrphans", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a72ee90130da054ca09b368a696627c83", null ],
    [ "ParaRegisterModeActive", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a81fad24b2a038b3cb1bc5157ac6339e4", null ],
    [ "ParaRightMargin", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a3ea3a3aad18ac347858caafeeb726977", null ],
    [ "ParaScaleWidthMaximum", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#af8a54c61198804f1bc5fc20537ef5478", null ],
    [ "ParaScaleWidthMinimum", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a2b365d2088f11ada61a1b64c7e916ada", null ],
    [ "ParaShadowFormat", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#ab06662e42c2a36f97ce4e18bbd0487aa", null ],
    [ "ParaSplit", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#afacdd63738ba4e3a08040e39289b0ecc", null ],
    [ "ParaStyleName", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#aeac9fbec555fddbf8219c8ea94ae7bd2", null ],
    [ "ParaTopMargin", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#ac6ca70814d30943ebe921504dd41ea8f", null ],
    [ "ParaUserDefinedAttributes", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a0b0bde2406663d5f6460ba94b23ae66a", null ],
    [ "ParaVertAlignment", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a067215b0b4788aba57fc66dcf94026db", null ],
    [ "ParaWidows", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a3072d8ed7bf43be2ae34409abaeb9a50", null ],
    [ "ParaWordSpacing", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#aa73036ac6184c50be858e0961a045dad", null ],
    [ "ParaWordSpacingMaximum", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a7a7a6085a7e251d3b9665e5dce9c16fe", null ],
    [ "ParaWordSpacingMinimum", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a950c52f87cfa65cf332cd3693d429a07", null ],
    [ "RightBorder", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a5a63000f5a2a2472e3e4ff55b3acea68", null ],
    [ "RightBorderDistance", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#aef3133d206f65e7c63e6f4e0b7e81a9b", null ],
    [ "SortedTextId", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a895e2661a30250caf988246e0078f203", null ],
    [ "TopBorder", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a17ab3611edf21b072bf9963d28fbba0d", null ],
    [ "TopBorderDistance", "servicecom_1_1sun_1_1star_1_1style_1_1ParagraphProperties.html#a244f38805668926e16165aab20b80f01", null ]
];
